@@ -1,5 +1,3 @@
-
-
 TVAR.gen <- function(data,B,TVARobject, Thresh, nthresh=1, type=c("simul","boot", "check"), n=200, lag=1, include = c("const", "trend","none", "both"),  
 thDelay=1,  thVar=NULL, mTh=1, starting=NULL, innov=rmnorm(n, mean=0, varcov=varcov), varcov=diag(1,k), show.parMat=FALSE, round=FALSE, seed){
 
@@ -203,6 +201,91 @@ thDelay=1,  thVar=NULL, mTh=1, starting=NULL, innov=rmnorm(n, mean=0, varcov=var
 
 
 
+
+
+#'Simulation of a multivariate Threshold Autoregressive model (TVAR)
+#'
+#'Simulate a multivariate Threshold VAR (TVAR)
+#'
+#'This function offers the possibility to generate series following a TVAR.
+#'
+#'By giving a matrix of coefficients, on can only simulate a VAR (nthresh=0) or
+#'TVAR (nthresh=1 or 2). One can have a specification with constant (default),
+#'trend, both or none (see arg include). Order in parameters is include/lags
+#'(VECM) and include/lags/include/lags for TVECM, hence, a matrix for a TVECM
+#'with 3 regimes, a const and a 2 lags would have 2 lines and 2*(1+4) columns.
+#'The innovations can be given by the user (a matrix of dim nxk, here n does
+#'not include the starting values!), by default it uses a multivariate normal
+#'distribution, with covariance matrix specified by varcov. The starting values
+#'(of dim lags x k) can be given. The user should take care for their choice,
+#'since it is not sure that the simulated values will cross the threshold even
+#'once.
+#'
+#'The matrix \sQuote{B} has to be in the form: constant, trend, lags, then
+#'repeated if many regimes. In case of uncertainty, using
+#'\code{who.parMat=TRUE} will print the matrix as interpreted by the function,
+#'helping the user to feed the right input.
+#'
+#'@aliases TVAR.sim VAR.sim
+#'@param B Matrix of coefficients to simulate
+#'@param Thresh The threshold value(s). Vector of length nthresh
+#'@param nthresh number of threshold (see details)
+#'@param n Number of observations to create when type="simul"
+#'@param lag Number of lags to include in each regime
+#'@param include Type of deterministic regressors to include. NOT WORKING
+#'PROPERLY CURRENTLY if not const
+#'@param thDelay 'time delay' for the threshold variable (as multiple of
+#'embedding time delay d) PLEASE NOTE that the notation is currently different
+#'to univariate models in tsDyn. The left side variable is taken at time t, and
+#'not t+1 as in univariate cases.
+#'@param thVar external transition variable
+#'@param mTh combination of variables with same lag order for the transition
+#'variable. Either a single value (indicating which variable to take) or a
+#'combination
+#'@param starting Starting values (matrix of dimension lag x k). If not given,
+#'set to zero.
+#'@param innov Innovations used for simulation. Should be matrix of dim n x k.
+#'By default multivariate normal.
+#'@param varcov Variance-covariance matrix for the innovations. By default
+#'identity matrix.
+#'@param show.parMat Logical. Should the parameter matrix be shown? Useful to
+#'understand how to give right input
+#'@param round Rounds the series created to have the same digits (hopefully) as
+#'original series.
+#'@param seed Optional. Seed for the random number generation.
+#'@param \dots Further arguments passed to the underlying (un-exported)
+#'\code{TVAR.gen} function
+#'@return A matrix with the simulated/bootstraped series.
+#'@author Matthieu Stigler
+#'@seealso \code{\link{TVAR}} to estimate a TVAR, \code{\link{VAR.sim}} to
+#'simulate/bootstrap a VAR, \code{\link{TVECM.sim}} to simulate/bootstrap a
+#'TVECM.
+#'@keywords ts bootstrap
+#'@examples
+#'
+#'##simulate VAR as in Enders 2004, p 268
+#'B1<-matrix(c(0.7, 0.2, 0.2, 0.7), 2)
+#'var1<-TVAR.sim(B=B1,nthresh=0,n=100, include="none")
+#'ts.plot(var1, type="l", col=c(1,2))
+#'
+#'
+#'B2<-rbind(c(0.5, 0.5, 0.5), c(0, 0.5, 0.5))
+#'varcov<-matrix(c(1,0.2, 0.3, 1),2)
+#'var2<-TVAR.sim(B=B2,nthresh=0,n=100, include="const", varcov=varcov)
+#'ts.plot(var2, type="l", col=c(1,2))
+#'
+#'
+#'##Simulation of a TVAR with 1 threshold
+#'B<-rbind(c(0.11928245, 1.00880447, -0.009974585, -0.089316, 0.95425564, 0.02592617),
+#'         c(0.25283578, 0.09182279,  0.914763741, -0.0530613, 0.02248586, 0.94309347))
+#'colnames(B) <- paste(rep(c("Const", "Lag_1_var1", "Lag_1_var2"), 2), c("Low", "High"), sep="_")
+#'sim<-TVAR.sim(B=B,nthresh=1,n=500, mTh=1, Thresh=5, starting=matrix(c(5.2, 5.5), nrow=1))
+#'
+#'#estimate the new serie
+#'TVAR(sim, lag=1, dummyToBothRegimes=TRUE)
+#'
+#'
+#'
 TVAR.sim <- function(B, Thresh, nthresh=1, n=200, lag=1, include = c("const", "trend","none", "both"),  thDelay=1,  
 thVar=NULL, mTh=1, starting=NULL, innov=rmnorm(n, mean=0, varcov=varcov), varcov=diag(1,nrow(B)), show.parMat=FALSE, round=FALSE, seed, ...){
 
@@ -210,6 +293,42 @@ thVar=NULL, mTh=1, starting=NULL, innov=rmnorm(n, mean=0, varcov=varcov), varcov
 		    thVar=thVar, mTh=mTh, starting=starting, innov=innov, varcov=varcov, show.parMat=show.parMat, round=round, seed=seed, ...)
 }
 
+
+
+#'Bootstrap a multivariate Threshold Autoregressive (TVAR) model
+#'
+#'Recursive bootstrap of a multivariate Threshold VAR (TVAR)
+#'
+#'The function bootstraps a given model. This is done on a object generated by
+#'TVECM (or VECM). A simple residual recursive bootstrap is done.
+#'
+#'@aliases TVAR.boot VAR.boot
+#'@param TVARobject Object of class \code{TVAR} generated by function
+#'\code{\link{TVAR}}
+#'@param VARobject Object of class \code{ VAR} generated by function
+#'\code{\link{lineVar}}
+#'@param innov Innovations used for bootstrap. If missing, residuals are
+#'resampled.
+#'@param seed Optional. Seed for the random resampling function.
+#'@param \dots Further arguments passed to the underlying (un-exported)
+#'\code{TVAR.gen} function
+#'@return A matrix with the bootstraped series.
+#'@author Matthieu Stigler
+#'@seealso \code{\link{TVAR}} to estimate a TVAR, \code{\link{VAR.sim}} to
+#'simulate/bootstrap a VAR, \code{\link{TVECM.sim}} to simulate/bootstrap a
+#'TVECM.
+#'@keywords ts bootstrap
+#'@examples
+#'
+#'
+#'
+#'##Bootstrap a TVAR with two threshold (three regimes)
+#'data(zeroyld)
+#'serie<-zeroyld
+#'mod <- TVAR(data=serie,lag=1, nthresh=1)
+#'TVAR.boot(mod)
+#'
+#'
 TVAR.boot <- function(TVARobject, innov, seed, ...){
   if(!inherits(TVARobject, "TVAR")) stop("Please provide an object of class 'TVAR' generated by TVAR()")
   TVAR.gen(TVARobject=TVARobject,type= "boot", innov = innov, seed=seed, ...)
@@ -220,6 +339,7 @@ innov=rmnorm(n, mean=0, varcov=varcov), varcov=diag(1,nrow(B)), show.parMat=FALS
   TVAR.gen(B=B, nthresh=0, type="simul", n=n, lag=lag, include = include,   starting=starting, innov=innov, varcov=varcov, show.parMat=show.parMat, round=round, seed=seed, ...)
 }
 
+#' @rdname TVAR.boot
 VAR.boot <- function(VARobject, innov, seed, ...){
   if(!inherits(VARobject, "VAR")) stop("Please provide an object of class 'VAR' generated by lineVar()")
   if(attr(VARobject, "varsLevel")!="level") stop("Does not work with VAR in diff or ADf specification")
@@ -236,21 +356,21 @@ environment(TVAR.boot)<-environment(star)
 
 ##Simulation of a TVAR with 1 threshold
 B<-rbind(c(0.11928245, 1.00880447, -0.009974585, -0.089316, 0.95425564, 0.02592617),c(0.25283578, 0.09182279,  0.914763741, -0.0530613, 0.02248586, 0.94309347))
-sim<-TVAR.sim(B=B,nthresh=1,n=500, type="simul",mTh=1, Thresh=5, starting=matrix(c(5.2, 5.5), nrow=1))
+sim<-TVAR.sim(B=B,nthresh=1,n=500,mTh=1, Thresh=5, starting=matrix(c(5.2, 5.5), nrow=1))
 
 #estimate the new serie
 TVAR(sim, lag=1, dummyToBothRegimes=TRUE)
 
 
 ##Bootstrap a TVAR 
-data(zeroyld)
+#data(zeroyld)
 serie<-zeroyld
 
-TVAR.sim(data=serie,nthresh=0, type="sim")
-all(TVAR.sim(data=serie,nthresh=0, type="check", lag=1)==serie)
+# TVAR.sim(data=serie,nthresh=0)
+# all(TVAR.sim(data=serie,nthresh=0, type="check", lag=1)==serie)
 
 ##with two threshold (three regimes)
-TVAR.sim(data=serie,nthresh=2,type="boot",mTh=1, Thresh=c(7,9))
+# TVAR.sim(data=serie,nthresh=2,type="boot",mTh=1, Thresh=c(7,9))
 
 environment(TVAR.sim)<-environment(star)
 
@@ -264,7 +384,7 @@ comp_tvar_sim <- function(mod, serie){
 }
 
 
-data(barry)
+#data(barry)
 var_l1_co <-lineVar(barry, lag=1, include="const")
 var_l1_tr <-lineVar(barry, lag=1, include="trend")
 var_l1_bo <-lineVar(barry, lag=1, include="both")
@@ -319,8 +439,8 @@ all.equal(tsDyn:::TVAR.gen(TVARobject=TVAR(serie, nthresh=1, lag=2, trace=FALSE)
 all.equal(tsDyn:::TVAR.gen(TVARobject=TVAR(serie, nthresh=2, lag=1, trace=FALSE),type="check"),as.matrix(serie), check.attributes=FALSE)
 all.equal(tsDyn:::TVAR.gen(TVARobject=TVAR(serie, nthresh=2, lag=2, trace=FALSE),type="check"),as.matrix(serie), check.attributes=FALSE)
 
-a1 <- TVAR.boot(TVARobject=lineVar(serie, lag=1))
-a2 <- TVAR.boot(TVARobject=lineVar(serie, lag=2))
+a1 <- VAR.boot(VARobject=lineVar(serie, lag=1))
+a2 <- VAR.boot(VARobject=lineVar(serie, lag=2))
 a3 <- TVAR.boot(TVARobject=TVAR(serie, nthresh=1, lag=1, trace=FALSE))
 
 }
