@@ -1,3 +1,103 @@
+#'Threshold Vector Error Correction model (VECM)
+#'
+#'Estimate a Threshold Vector Error Correction model (VECM)
+#'
+#'For fixed threshold and cointegrating vector, the model is linear, so
+#'estimation of the regression parameters can be done directly by CLS
+#'(Conditional Least Squares). The search of the threshold and cointegrating
+#'parameters values which minimize the residual sum of squares (SSR) is made on
+#'a grid of potential values. For specification of the grids, see below.
+#'
+#'The function can estimate one as well as two thresholds:
+#'
+#'\describe{ \item{nthresh=1:}{ estimation of one threshold model (two regimes)
+#'upon a grid of \var{ngridTh} values (default to ALL) possible thresholds and
+#'delays values. }
+#'
+#'\item{nthresh=2:}{estimation of two thresholds model (three regimes).
+#'Conditional on the threshold found in model where nthresh=1, the second
+#'threshold is searched. When both are found, a second grid search is made with
+#'30 values around each threshold.} }
+#'
+#'The model can be either with a threshold effect on all variables ("All") or
+#'only on the error correction term (ECT) (argument "only ECT"). In the second
+#'case, the value for the middle threshold is taken a null, as in Balke and
+#'Fomby (1997).
+#'
+#'The grid for the threshold parameters can be set in different ways, through
+#'the argument \var{th1}, \var{th2} and \var{beta}:
+#'
+#'\describe{ \item{exact:}{Pre-specified value. } \item{int:}{Specify an
+#'interval (of length \var{ngridTh}) in which to search.}
+#'\item{around:}{Specify to take \var{ngridTh} points around the value given. }
+#'}
+#'
+#'The default is to do an interval search. Interval bounds for the threshold
+#'interval are simply the \var{trim} and 1-\var{trim} percents of the sorted
+#'error correction term.  For the cointegrating parameter, bounds of the
+#'interval are obtained from the (OLS) confidence interval of the linear
+#'cointegration case.  It is often found however that this interval is too
+#'tight. It is hence recommended to inspect the plot of the grid search.
+#'
+#'@param data time series
+#'@param lag Number of lags to include in each regime
+#'@param nthresh number of threshold (see details)
+#'@param trim trimming parameter indicating the minimal percentage of
+#'observations in each regime
+#'@param ngridBeta number of elements to search for the cointegrating value
+#'@param ngridTh number of elements to search for the threshold value
+#'@param plot Whether the grid with the SSR of each threshold should be ploted.
+#'@param th1 different possibilities to pre-specify an exact value, an interval
+#'or a central point for the search of the threshold (or first threshold if
+#'nthresh=2)
+#'@param th2 different possibilities to pre-specify an exact value or a central
+#'point for the search of the second threshold (used only if nthresh=2)
+#'@param beta different possibilities to pre-specify an exact value, an
+#'interval or a central point for the search of the cointegrating value
+#'@param restr Currently not avalaible
+#'@param common Whether the regime-specific dynamics are only for the ECT or
+#'for the ECT and the lags
+#'@param include Type of deterministic regressors to include
+#'@param dummyToBothRegimes Whether the dummy in the one threshold model is
+#'applied to each regime or not.
+#'@param beta0 Additional regressors to include in the cointegrating relation
+#'@param methodMapply only for programming. Is to make the choice between a for
+#'loop or \code{mapply} implementation
+#'@param trace should additional infos be printed? (logical)
+#'@return Fitted model data
+#'@author Matthieu Stigler
+#'@seealso \code{\link{VECM}} for the linear VECM, \code{\link{TVAR}} for the
+#'threshold VAR, \code{\link{TVECM.SeoTest}} to test for TVECM,
+#'\code{\link{TVECM.sim}} to simulate/bootstrap a TVECM.
+#'@references Hansen, B. and Seo, B. (2002), Testing for two-regime threshold
+#'cointegration in vector error-correction models, Journal of Econometrics,
+#'110, pages 293 - 318
+#'
+#'Seo, M. H. (2009) Estimation of non linear error-correction models, Working
+#'paper
+#'@keywords ts
+#'@examples
+#'
+#'
+#'data(zeroyld)
+#'data<-zeroyld
+#'
+#'##Estimate a TVECM (we use here minimal grid, it should be usually much bigger!)
+#'
+#'tv<-TVECM(data, nthresh=2,lag=1, ngridBeta=20, ngridTh=30, plot=TRUE,trim=0.05, common="All")
+#'
+#'print(tv)
+#'summary(tv)
+#'
+#'#Obtain diverse infos:
+#'AIC(tv)
+#'BIC(tv)
+#'
+#'res.tv<-residuals(tv)
+#'
+#'#export the equations as Latex:
+#'toLatex(tv)
+#'
 TVECM<-function(data,lag=1,nthresh=1, trim=0.05, ngridBeta=50, ngridTh=50, plot=TRUE,  th1=list(exact=NULL, int=c("from","to"), around="val"), th2=list(exact=NULL, int=c("from","to"), around="val"), beta=list(exact=NULL, int=c("from","to"), around=c("val","by")), restr=c("none", "equal", "signOp"), common=c("All", "only_ECT"), include = c( "const", "trend","none", "both"),dummyToBothRegimes=TRUE,beta0=0,methodMapply=FALSE, trace=TRUE ) {
 
 ##check args
@@ -24,7 +124,7 @@ k<-ncol(y) #k: Number of equations
 
 if(k>2 & is.null(beta$exact))
   stop("Sorry, the search is only possible with 2 variables. If more, please provide pre-specified beta values")
-if(is.null(colnames(data))==TRUE)
+if(is.null(colnames(data)))
   colnames(data)<-paste("Var", c(1:k), sep="")
 ndig<-getndp(y)
 
@@ -90,14 +190,12 @@ allpar<-ncol(B)*nrow(B)
 
 rownames(B)<-paste("Equation",colnames(data))
 LagNames<-c(paste(rep(colnames(data),p), -rep(seq_len(p), each=k)))
-if(include=="const")
-  colnames(B)<-c("ECT","Intercept",LagNames)
-else if(include=="trend")
-  colnames(B)<-c("ECT","Trend",LagNames)
-else if(include=="both")
-  colnames(B)<-c("ECT","Intercept","Trend",LagNames)
-else
-  colnames(B)<-c("ECT",LagNames)
+colnames(B)<-switch(include, 
+		    "const"=c("ECT","Intercept",LagNames),
+		    "trend"=c("ECT","Trend",LagNames), 
+		    "both"=c("ECT","Intercept","Trend",LagNames),
+		    "none"=c("ECT",LagNames))
+
 res<-Y-Z%*%t(B)
 
 Sigma<- matrix(1/t*crossprod(res),ncol=k,dimnames=list(colnames(data), colnames(data)))
@@ -109,9 +207,9 @@ Pval<-pt(abs(Tvalue), df=(t-ncol(Z)), lower.tail=FALSE)+pt(-abs(Tvalue), df=(t-n
 colnames(Pval)<-colnames(B)
 
 
-nlike<-log(det(Sigma)) # nlike=(t/2)*log(det(sige));
-aic<-t*nlike+2*(allpar)
-bic<-t*nlike+log(t)*(allpar) #bic #=nlike+log10(t)*4*(1+k); ###BIC
+# nlike<-log(det(Sigma)) # nlike=(t/2)*log(det(sige));
+# aic<-t*nlike+2*(allpar)
+# bic<-t*nlike+log(t)*(allpar) #bic #=nlike+log10(t)*4*(1+k); ###BIC
 #########################
 ###Set up of the grid
 #########################
@@ -272,7 +370,8 @@ oneSearch<-function(betas, gammas){
 ###Plot results of grid search
   if(is.null(gamma1$exact)==FALSE&is.null(beta$exact)==FALSE){plot<-FALSE}
 
-  if(plot==TRUE){
+
+  if(plot){
     if(!is.null(beta$exact)&is.null(gamma1$exact)){ #only gamma estimated
       plot(gammas,store, type="l", xlab="Threshold parameter gamma", ylab="Residual Sum of Squares", main="Grid Search")
       points(x=bestGamma1, y=min(store, na.rm=TRUE), col=2, cex=2)
@@ -322,8 +421,7 @@ if(nthresh==2){
     n1<-mean(d1) #Number of elements of the ECT under the threshold
     d2<-ifelse(ECTi>gam2,1,0)
     n2<-mean(d2)
-    if(is.na(n1)==TRUE) {n1<-0; n2<-0}
-                                        # print(c(n1, 1-n1-n2,n2))
+    if(is.na(n1)) n1<-n2<-0
     if (min(n1,n2,1-n1-n2)>trim) {
       ziUnder<-c(d1)*zi
       ziOver<-c(d2)*zi
@@ -349,7 +447,7 @@ if(nthresh==2){
     d2<-ifelse(ECTi>gam2,1,0)
     n2<-mean(d2)
 # print(c(n1, 1-n1-n2,n2))
-    if(is.na(n1)==TRUE) {n1<-0; n2<-0}
+    if(is.na(n1)) {n1<-0; n2<-0}
     if (min(n1,n2,1-n1-n2)>trim) {
       ectUnder<-c(d1)*ECTi
       ectOver<-c(d2)*ECTi
@@ -383,6 +481,7 @@ if(nthresh==2){
     wh.thresh <- which.min(abs(allgammas-bestThresh))
     ninter<-round(trim*nrow(Xminus1))
 
+### Conditional search without restriction
     if(restr=="none"){
 #search for a second threshold smaller than the first
       if(wh.thresh>2*ninter){
@@ -437,7 +536,7 @@ if(nthresh==2){
     
     if(trace)
       cat("Second best (conditionnal on the first one)", c(bestThresh,secondBestThresh), "\t SSR", min(store2, na.rm=TRUE), "\n")
-  }#end if ...many conditions
+  }#end if both th1 and th2 exact
   
   
 ###Iterative step
@@ -532,8 +631,7 @@ if(nthresh==2){
     Zover<-c(d2)*Z_temp
     Zmiddle<-(1-c(d1)-c(d2))*Z_temp
     Zbest<-cbind(Zunder,Zmiddle, Zover)
-  }
-  if(model=="only_ECT"){
+  }else if(model=="only_ECT"){
     Zunder<-c(d1)*ECT_best
     Zover<-c(d2)*ECT_best
     Zbest<-cbind(Zunder,Zover, DeltaX)
@@ -609,7 +707,7 @@ return(z)
 
 if(FALSE) {
 library(tsDyn)
-data(zeroyld)
+#data(zeroyld)
 dat<-zeroyld
 
 environment(TVECM)<-environment(star)
@@ -706,7 +804,7 @@ print.summary.TVECM<-function(x,...){
   cat("\nPercentage of Observations in each regime", percent(x$model.specific$nobs,digits=3,by100=TRUE), "\n")
 }
 
-toLatex.TVECM<-function(object,digits=4,parenthese=c("StDev","Pvalue"),...){
+toLatex.TVECM<-function(object,digits=4,parenthese=c("StDev","Pvalue"),label, ...){
   x<-object
   Th<-x$model.specific$Thresh
   nthresh<-length(Th)
@@ -740,6 +838,8 @@ toLatex.TVECM<-function(object,digits=4,parenthese=c("StDev","Pvalue"),...){
   res[3]<-"%\\usepackage{amsmath} \\newenvironment{smatrix}{\\left(\\begin{smallmatrix}}{\\end{smallmatrix}\\right)} %SMALL"
   res[4]<-"%\\usepackage{nccmath} \\newenvironment{smatrix}{\\left(\\begin{mmatrix}}{\\end{mmatrix}\\right)} %MEDIUM"
   res[5]<-"\\begin{equation}"
+  if(!missing(label)) res[5]<- paste(res[5], "\\label{", label, "}", sep="")
+
 ###Explained vector
   res[6]<- "\\begin{smatrix} %explained vector"
   res[7]<-TeXVec(paste("slashDelta X_{t}^{",seq(1, x$k),"}", sep=""))
