@@ -107,22 +107,3 @@ oneStep.linear <- function(object, newdata, ...) {
 	cbind(1,newdata) %*% object$coefficients
 }
 
-showDialog.linear <- function(x, ...) {
-	frRoot <- Frame()
-	vM <- tclVar(1)
-	vD <- tclVar(1)
-	vSteps <- tclVar(1)
-	onFinish <- function() {
-		res <- linear(x, m=as.numeric(tclObj(vM)), d=as.numeric(tclObj(vD)), steps=as.numeric(tclObj(vSteps)) )
-		tkdestroy(frRoot$tkvar)
-		assign("nlarModel", res, .GlobalEnv)
-	}
-	onCancel <- function()
-		tkdestroy(frRoot$tkvar)
-	frMain <- nlar.struct.Frame(vM, vD, vSteps)
-	add(frRoot,
-		frMain,
-		makeButtonsFrame(list(Finish=onFinish, Cancel=onCancel))
-	)
-	buildDialog(title="linear model", frRoot)
-}
