@@ -1,10 +1,40 @@
+#'VAR representation
+#'
+#'Show the VAR representation of a VECM
+#'
+#'
+#'@aliases VARrep VARrep.VECM VARrep.VAR
+#'@param object An object of class \sQuote{VECM} created by \code{\link{VECM}},
+#'or of class \sQuote{VAR} created by \code{\link{lineVar}}
+#'@param \dots Currently not used
+#'@return A matrix containing the parameters of the VECM under their VAR
+#'representation.
+#'@author Matthieu Stigler
+#'@references Hamilton (1994) \emph{Time Series Analysis}, Princeton University
+#'Press
+#'@keywords ts VECM VAR cointegration
+#'@examples
+#'
+#'
+#'data(barry)
+#'
+#'# VECM model:
+#'mod_vecm <- VECM(barry, lag=2, estim="ML")
+#'VARrep(mod_vecm)
+#'
+#'# VAR model:
+#'mod_var <- lineVar(barry, lag=2, I="diff")
+#'VARrep(mod_var)
+#'
+#'
 
-
-########### VAR Representation
+#' @export
 VARrep  <- function (object, ...)  
   UseMethod("VARrep")
 
-
+#' @rdname VARrep
+#' @method VARrep VECM
+#' @S3method VARrep VECM
 VARrep.VECM <- function(object, ...) {
 
   lag <- object$lag
@@ -59,16 +89,28 @@ VARrep.VECM <- function(object, ...) {
     Amat <- cbind(Pi_deter,Amat)
   }
   rownames(Amat) <- gsub("Equation ","",rownames(co))
+
+## Add exogen terms
+  if(object$exogen){
+    co_exo <- co[,object$num_exogen]
+    Amat <- cbind(Amat, co_exo)
+  }
+
 ## res
   Amat
 }
 
+#' @rdname VARrep
+#' @method VARrep VAR
+#' @S3method VARrep VAR
 VARrep.VAR <- function(object, ...) {
 
   I <- attr(object, "varsLevel")
 
-  if(I=="level"){
-    res <- object
+  if(I=="ADF"){
+    stop("Sorry, VARrep not yet implemented for type=ADF. Please use corresponding level formulation with lag+1")
+  } else if(I=="level"){
+    res <- coef(object)
   } else if(I=="diff"){
     lag <- object$lag
     k <- object$k
@@ -90,15 +132,20 @@ VARrep.VAR <- function(object, ...) {
   ## names
     colnames(comat) <- paste(rep(origNames, lag+1), rep(1:(lag+1), each=k), sep=".l")
 
+  ## add deterministic terms
     if(include!="none"){
       inc_name <- switch(include, "none"=NULL, "const"="Intercept", "trend"="Trend", "both"=c("Intercept","Trend"))
       comat <- cbind(co[,inc_name,drop=FALSE], comat)
     }
     res <- comat
+  ## Add exogen terms
+    if(object$exogen){
+      co_exo <- co[,object$num_exogen]
+      res <- cbind(res, co_exo)
+    }
+
+  } 
 
-  } else if(I=="ADF"){
-    stop("Sorry, VARrep not yet implemented for type=ADF. Please use corresponding level formulation with lag+1")
-  }
 
 ##
 return(res)
@@ -332,7 +379,7 @@ if(FALSE){
 
 library(tsDyn)
 
-data(zeroyld)
+#data(zeroyld)
 vec1 <- VECM(zeroyld, lag=2, estim="ML")
 predict(vec1 )
 tsDyn:::predictOld.VECM(vec1, n.ahead=5)
@@ -344,7 +391,7 @@ varpToDf <- function(x) matrix(sapply(x$fcst, function(x) x[,"fcst"]), nrow=nrow
 
 ### Comparisons
 library(vars)
-data(Canada)
+#data(Canada)
 n <- nrow(Canada)
 
 VECM_tsD <- VECM(Canada, lag=2, estim="ML")
@@ -381,7 +428,7 @@ all.equal(predict(VECM_tsD)$endog,predict(VECM_vars)$endog)
 
 
 ### compare VARrep
-data(denmark)
+#data(denmark)
 dat_examp <- denmark[,2:3]
 
 
